#!/bin/bash

QUIET_ARG=""
[ "$1" == "--quiet" ] && QUIET_ARG="--quiet"

# Enter source directory
cd $( dirname $0 )

if [ -d venv ]
then
	VENV=$( realpath venv )
	TEMP_VENV=0
else
	# Create a temporary venv
	VENV=$(mktemp -d)
	echo "Create a temporary virtualenv in $VENV to install dependencies..."
	TEMP_VENV=1
	python3 -m venv $VENV
fi

echo "Install package with dev dependencies using pip..."
$VENV/bin/python3 -m pip install -e ".[dev]" $QUIET_ARG

RES=0

# Run pre-commit
echo "Run pre-commit..."
source $VENV/bin/activate
pre-commit run --all-files
[ $? -ne 0 ] && RES=1

# Clean temporary venv
[ $TEMP_VENV -eq 1 ] && rm -fr $VENV

exit $RES
